@@ -8,14 +8,14 @@
 # of the KOLLA_BOOTSTRAP variable being set, including empty.
 if [[ "${!KOLLA_BOOTSTRAP[@]}" ]]; then
     nova-manage api_db sync
-    nova-manage db sync --local_cell
+    nova-manage db sync
     nova-manage db online_data_migrations
     exit 0
 fi
 
 if [[ "${!KOLLA_UPGRADE[@]}" ]]; then
     nova-manage api_db sync
-    nova-manage db sync --local_cell
+    nova-manage db sync
     exit 0
 fi
 
@@ -24,4 +24,9 @@ if [[ "${!KOLLA_OSM[@]}" ]]; then
     exit 0
 fi
 
+if [[ "${!KOLLA_UPGRADE_CHECK[@]}" ]]; then
+    nova-status upgrade check
+    exit $?
+fi
+
 . /usr/local/bin/kolla_httpd_setup
